==> firefly-design-data-1.0-20230619.153219-113-sources.jar: com/firefly/design/invitation/config/TurnInvitationConfig.java <==
package com.firefly.design.invitation.config;

import com.firefly.design.invitation.InvitationAddress;
import com.firefly.design.invitation.TurnAutoplay;
import com.firefly.design.si.DocumentType;
import lombok.*;

import java.util.Objects;

@ToString(callSuper = true)
@EqualsAndHashCode(callSuper = true)
@Getter
@Setter
public class TurnInvitationConfig extends InvitationConfig{



    /**
     * 自动播放
     */
    private TurnAutoplay autoplay;


    /**
     * 启用祝福
     */
    private boolean enabledComment = false;

    /**
     * 隐藏祝福弹幕
     */
    public boolean hiddenComment = false;

    /**
     * 禁止新的祝福弹幕
     */
    private boolean disabledNewComment = false;

    /**
     * 启用强制自动打开
     * - 当有音乐，自动播放失败时候。需设置true才会自动打开
     */
    private boolean enabledForceAutoOpen = false;


    /**
     * 封面文档ID
     */
    private String envelopeId;

    /**
     * 地址
     */
    private InvitationAddress address;

    public static final DocumentType TYPE = DocumentType.valueOf("page/turn");
    public TurnInvitationConfig() {
        super(TYPE);
    }


    @Override
    public TurnInvitationConfig clone() {
        TurnInvitationConfig clone = (TurnInvitationConfig) super.clone();
        clone.setPrimaryColor(this.getPrimaryColor());
//        clone.setDisabledAdvert(this.isDisabledAdvert());
        clone.setEnabledComment(this.enabledComment);
        clone.setHiddenComment(this.hiddenComment);
        clone.setDisabledNewComment(this.disabledNewComment);
        clone.setEnabledForceAutoOpen(this.enabledForceAutoOpen);
        clone.setEnvelopeId(this.envelopeId);
        if (Objects.nonNull(this.address)) {
            clone.setAddress(this.address.clone());
        }
        return clone;
    }

}

==> firefly-design-data-3.0-20230904.150710-1-sources.jar: com/firefly/design/invitation/config/TurnInvitationConfig.java <==
package com.firefly.design.invitation.config;

import com.firefly.design.invitation.InvitationAddress;
import com.firefly.design.invitation.TurnInvitation;
import lombok.*;

import java.util.Objects;

@ToString(callSuper = true)
@EqualsAndHashCode(callSuper = true)
@Getter
@Setter
public class TurnInvitationConfig extends InvitationConfig{



    /**
     * 自动播放
     */
    private TurnAutoplay autoplay;


    /**
     * 启用祝福
     */
    private boolean enabledComment = false;

    /**
     * 隐藏祝福弹幕
     */
    public boolean hiddenComment = false;

    /**
     * 禁止新的祝福弹幕
     */
    private boolean disabledNewComment = false;

    /**
     * 启用强制自动打开
     * - 当有音乐，自动播放失败时候。需设置true才会自动打开
     */
    private boolean enabledForceAutoOpen = false;


    /**
     * 封面文档ID
     */
    private String envelopeId;

    /**
     * 地址
     */
    private InvitationAddress address;

    public TurnInvitationConfig() {
        super(TurnInvitation.TYPE);
    }


    @Override
    public TurnInvitationConfig clone() {
        TurnInvitationConfig clone = (TurnInvitationConfig) super.clone();
        clone.setPrimaryColor(this.getPrimaryColor());
//        clone.setDisabledAdvert(this.isDisabledAdvert());
        clone.setEnabledComment(this.enabledComment);
        clone.setHiddenComment(this.hiddenComment);
        clone.setDisabledNewComment(this.disabledNewComment);
        clone.setEnabledForceAutoOpen(this.enabledForceAutoOpen);
        clone.setEnvelopeId(this.envelopeId);
        if (Objects.nonNull(this.address)) {
            clone.setAddress(this.address.clone());
        }
        return clone;
    }

}
